from datetime import date

FULL_PAYMENT_DEADLINE = date(year=2021, month=3, day=31)
CANCELLATION_DEADLINE = date(year=2021, month=4, day=1)
COST_FULL = 1150
COST_DISTRICT_CONVENTION = 280
COST_BANQUET = 400
COST_MD_CONVENTION = 320
COST_THEME = 400
COST_PINS = 55
